@@ -51,9 +51,9 @@ static char sccsid[] = "@(#)column.c	8.3 (Berkeley) 4/2/94";
 #include <stdlib.h>
 #include <string.h>
 
-#ifdef __linux__
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
-#endif /* __linux__ */
+#endif /* HAVE_UNISTD_H */
 
 void  c_columnate __P((void));
 void *emalloc __P((int));
