@@ -46,13 +46,13 @@ static char sccsid[] = "@(#)display.c	8.1 (Berkeley) 6/6/93";
 #include <string.h>
 #include "hexdump.h"
 
-#if defined __linux__ && !defined __GLIBC__
+#if defined DEBIAN && !defined __GLIBC__
 #define MIN(a, b)		((a) < (b) ? (a) : (b))
 #ifdef __GNUC__
 typedef long long		quad_t;
 typedef unsigned long long	u_quad_t;
 #endif /* __GNUC__ */
-#endif /* __linux__ */
+#endif /* DEBIAN */
 
 enum _vflag vflag = FIRST;
 
