@@ -65,10 +65,10 @@ static char sccsid[] = "@(#)look.c	8.1 (Berkeley) 6/14/93";
 #include <ctype.h>
 #include "pathnames.h"
 
-#ifdef __linux__
+#ifdef HAVE_UNISTD_H
 #define SIZE_T_MAX UINT_MAX
 #include <unistd.h>
-#endif /* __linux__ */
+#endif /* HAVE_UNISTD_H */
 
 /*
  * FOLD and DICT convert characters to a normal form for comparison,
@@ -82,8 +82,8 @@ static char sccsid[] = "@(#)look.c	8.1 (Berkeley) 6/14/93";
 #define	LESS		(-1)
 #define NO_COMPARE	(-2)
 
-#define	FOLD(c)	(isascii(c) && isupper(c) ? tolower(c) : (c))
-#define	DICT(c)	(isascii(c) && isalnum(c) ? (c) : NO_COMPARE)
+#define	FOLD(c)	(isupper(c) ? tolower(c) : (c))
+#define	DICT(c)	(isalnum(c) ? (c) : NO_COMPARE)
 
 int dflag, fflag;
 
@@ -143,25 +143,25 @@ main(argc, argv)
 		*++p = '\0';
 
 	fd = open(file, O_RDONLY, 0);
-#ifdef __linux__
+#ifdef DEBIAN
 	if (fd < 0 && errno == ENOENT && default_dict) {
 		fd = open(_PATH_WORDS2, O_RDONLY, 0);
 		if (!(fd < 0 && errno == ENOENT))
 			file = _PATH_WORDS2;
 	}
-#endif /* __linux__ */
+#endif /* DEBIAN */
 	if (fd < 0 || fstat(fd, &sb))
 		err("%s: %s", file, strerror(errno));
 
 	if (sb.st_size > SIZE_T_MAX)
 		err("%s: %s", file, strerror(EFBIG));
-#ifdef __linux__
+#ifdef __unix__
 	if ((front = mmap(NULL, (size_t)sb.st_size, PROT_READ,
 			  MAP_FILE | MAP_SHARED, fd, (off_t)0)) == NULL)
-#else /* not __linux__ */
+#else /* not __unix__ */
 	if ((front = mmap(NULL, (size_t)sb.st_size, PROT_READ,
 			  0, fd, (off_t)0)) == NULL)
-#endif /* not __linux__ */
+#endif /* not __unix__ */
 		err("%s: %s", file, strerror(errno));
 	back = front + sb.st_size;
 	exit(look(string, front, back));
